@@ -113,7 +113,7 @@ class CleverSession(CleverDict):
         """
         self.check_and_prompt("url", "username", "password")
         if not hasattr(self, "browsers"):
-            self.browsers = []
+            self.setattr_direct(browsers, [])
         dispatch = {"github.com": Login_to.github,
                     "twitter.com": Login_to.twitter,
                     "satchelone.com": Login_to.satchelone}
